# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2024-11-23
### Added
- Added 2x2x2, 4x4x4, 5x5x5, 6x6x6 and 7x7x7 scramble feature.
- Added 2x2x2, 4x4x4, 5x5x5, 6x6x6 and 7x7x7 cube net display feature.
- Added user-input scramble feature.

### Changed
- Changed UI style.
- Changed cube net display.
- Changed the size when the blocking screen is displayed.

### Fixed
- Fixed crash at startup.

## [0.1.0] - 2024-11-10
### Added
- Added 3x3x3 scramble feature.
- Added 3x3x3 cube net display feature.
- Added timer feature.
- Added blocking screen when too small app size.

[0.2.0]: https://github.com/sou-san/sctt/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/sou-san/sctt/releases/tag/v0.1.0
